@@ -9,7 +9,7 @@ import fire
 class Regbot:
   reg_model_path = resource_filename(__name__, 'finalized_model.h5') 
   model_scaler_path = resource_filename(__name__, 'logscaler.gz') 
-  thr = 0.3
+
 
   def __init__(self,*args):
   	pass
@@ -26,7 +26,7 @@ class Regbot:
   def prepareInput(cls,opening,closing):
     avr = closing/(opening + closing)
     bvr = opening/(opening + closing)
-    testdata = np.array([[avr,bvr]])
+    testdata = np.array([avr,bvr])
     scaler = joblib.load(f'{cls.model_scaler_path}')
     testdata = scaler.transform(testdata)
 
@@ -36,11 +36,14 @@ class Regbot:
   @classmethod
   def buySignalGenerator(cls,opening,closing):
     scalledInput = cls.prepareInput(opening,closing)
-    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > cls.thr).astype(int)[0]
+    return (cls.loadmodel().predict_proba(scalledInput)[:,1] > 0.0).astype(int)[0]
+    #return (cls.loadmodel().predict(scalledInput) > 0).astype(int)[0]
     
 
 
 
+
+
 def signal(opening,closing):
   try:
     return Regbot.buySignalGenerator(opening,closing)
